@@ -6,6 +6,8 @@ from vietocr.tool.translate import build_model
 from vietocr.tool.translate import translate, batch_translate_beam_search
 from vietocr.tool.utils import download_weights
 from vietocr.tool.logger import Logger
+from vietocr.loader.aug import ImgAugTransform
+
 import yaml
 import torch
 from vietocr.loader.DataLoader import DataGen
@@ -70,10 +72,12 @@ class Trainer():
 #        self.criterion = nn.CrossEntropyLoss(ignore_index=0) 
         self.criterion = LabelSmoothingLoss(len(self.vocab), padding_idx=self.vocab.pad, smoothing=0.1)
         
-        transforms = torchvision.transforms.Compose([
-            torchvision.transforms.ColorJitter(brightness=.1, contrast=.1, hue=.1, saturation=.1),
-            torchvision.transforms.RandomAffine(degrees=0, scale=(3/4, 4/3))
-            ])
+#        transforms = torchvision.transforms.Compose([
+#            torchvision.transforms.ColorJitter(brightness=.1, contrast=.1, hue=.1, saturation=.1),
+#            torchvision.transforms.RandomAffine(degrees=0, scale=(3/4, 4/3))
+#            ])
+        
+        transforms = ImgAugTransform()
 
         self.train_gen = self.data_gen('train_{}'.format(self.dataset_name), 
                 self.data_root, self.train_annotation, transform=transforms)
@@ -88,6 +92,7 @@ class Trainer():
         
         total_loader_time = 0
         total_gpu_time = 0
+        best_acc = 0
 
         data_iter = iter(self.train_gen)
         for i in range(self.num_iters):
@@ -130,7 +135,11 @@ class Trainer():
                 self.logger.log(info)
 
                 self.save_checkpoint(self.checkpoint)
-                self.save_weight(self.export_weights)
+
+                if acc_full_seq > best_acc:
+                    self.save_weight(self.export_weights)
+                    best_acc = acc_full_seq
+
             
     def validate(self):
         self.model.eval()
@@ -194,7 +203,7 @@ class Trainer():
     
         return acc_full_seq, acc_per_char
     
-    def visualize_prediction(self, sample=16, errorcase=False, fontname='serif'):
+    def visualize_prediction(self, sample=16, errorcase=False, fontname='serif', fontsize=20):
         
         pred_sents, actual_sents, img_files = self.predict(sample)
 
@@ -210,7 +219,12 @@ class Trainer():
 
 
         img_files = img_files[:sample]
-        
+
+        fontdict = {
+                'family':fontname,
+                'size':fontsize
+                } 
+
         for vis_idx in range(0, len(img_files)):
             img_path = img_files[vis_idx]
             pred_sent = pred_sents[vis_idx]
@@ -219,7 +233,7 @@ class Trainer():
             img = Image.open(open(img_path, 'rb'))
             plt.figure()
             plt.imshow(img)
-            plt.title('pred: {} - actual: {}'.format(pred_sent, actual_sent), loc='left', fontname=fontname)
+            plt.title('pred: {} - actual: {}'.format(pred_sent, actual_sent), loc='left', fontdict=fontdict)
             plt.axis('off')
 
         plt.show()
